@@ -1,9 +1,10 @@
+import glob
 import os
-import fnmatch
-import sys
+import warnings
 
 from circus import logger
 from circus.util import (DEFAULT_ENDPOINT_DEALER, DEFAULT_ENDPOINT_SUB,
+                         DEFAULT_ENDPOINT_MULTICAST, DEFAULT_ENDPOINT_STATS,
                          StrictConfigParser, parse_env_str)
 try:
     import gevent       # NOQA
@@ -69,48 +70,37 @@ def read_config(config_path):
     cfg = DefaultConfigParser()
     with open(config_path) as f:
         cfg.readfp(f)
-    cfg_files_read = [config_path]
 
     current_dir = os.path.dirname(config_path)
 
     # load included config files
     includes = []
 
-    def include_filename(filename):
-        if '*' in filename:
-            include_dir = os.path.dirname(filename)
-            if os.path.abspath(filename) != filename:
-                include_dir = os.path.join(current_dir,
-                                           os.path.dirname(filename))
+    def _scan(filename, includes):
+        if os.path.abspath(filename) != filename:
+            filename = os.path.join(current_dir, filename)
 
-            wildcard = os.path.basename(filename)
-            for root, dirnames, filenames in os.walk(include_dir):
-                for filename in fnmatch.filter(filenames, wildcard):
-                    cfg_file = os.path.join(root, filename)
-                    includes.append(cfg_file)
-
-        elif os.path.isfile(filename):
-            includes.append(filename)
+        paths = glob.glob(filename)
+        if paths == []:
+            raise IOError('%r does not lead to any config. Make sure '
+                          'include paths are relative to the main config '
+                          'file')
+        includes += paths
 
     for include_file in cfg.dget('circus', 'include', '').split():
-        include_filename(include_file)
+        _scan(include_file, includes)
 
     for include_dir in cfg.dget('circus', 'include_dir', '').split():
-        include_filename(os.path.join(include_dir, '*.ini'))
+        _scan(os.path.join(include_dir, '*.ini'), includes)
 
-    logger.debug('reading config files: %s' % includes)
-
-    cfg_files_read.extend(cfg.read(includes))
-
-    return cfg, cfg_files_read
+    logger.debug('Reading config files: %s' % includes)
+    return cfg, [config_path] + cfg.read(includes)
 
 
 def get_config(config_file):
     if not os.path.exists(config_file):
-        sys.stderr.write("the configuration file %r does not exist\n" %
-                         config_file)
-        sys.stderr.write("Exiting...\n")
-        sys.exit(1)
+        raise IOError("the configuration file %r does not exist\n" %
+                      config_file)
 
     cfg, cfg_files_read = read_config(config_file)
     dget = cfg.dget
@@ -121,12 +111,27 @@ def get_config(config_file):
     config['endpoint'] = dget('circus', 'endpoint', DEFAULT_ENDPOINT_DEALER)
     config['pubsub_endpoint'] = dget('circus', 'pubsub_endpoint',
                                      DEFAULT_ENDPOINT_SUB)
-    config['stats_endpoint'] = dget('circus', 'stats_endpoint', None, str)
+    config['multicast_endpoint'] = dget('circus', 'multicast_endpoint',
+                                        DEFAULT_ENDPOINT_MULTICAST)
+    config['stats_endpoint'] = dget('circus', 'stats_endpoint', None)
+    config['statsd'] = dget('circus', 'statsd', False, bool)
+
+    if config['stats_endpoint'] is None:
+        config['stats_endpoint'] = DEFAULT_ENDPOINT_STATS
+    elif not config['statsd']:
+        warnings.warn("You defined a stats_endpoint without "
+                      "setting up statsd to True.",
+                      DeprecationWarning)
+        config['statsd'] = True
+
     config['warmup_delay'] = dget('circus', 'warmup_delay', 0, int)
     config['httpd'] = dget('circus', 'httpd', False, bool)
     config['httpd_host'] = dget('circus', 'httpd_host', 'localhost', str)
     config['httpd_port'] = dget('circus', 'httpd_port', 8080, int)
     config['debug'] = dget('circus', 'debug', False, bool)
+    config['pidfile'] = dget('circus', 'pidfile')
+    config['loglevel'] = dget('circus', 'loglevel')
+    config['logoutput'] = dget('circus', 'logoutput')
 
     # Initialize watchers, plugins & sockets to manage
     watchers = []
@@ -178,7 +183,7 @@ def get_config(config_file):
                                                      True, bool)
                 elif opt == 'max_retry':
                     watcher['max_retry'] = dget(section, "max_retry", 5, int)
-                elif opt == 'graceful_timout':
+                elif opt == 'graceful_timeout':
                     watcher['graceful_timeout'] = dget(
                         section, "graceful_timeout", 30, int)
                 elif opt.startswith('stderr_stream') or \
@@ -223,6 +228,14 @@ def get_config(config_file):
                 elif opt == 'autostart':
                     watcher['autostart'] = dget(section, "autostart", True,
                                                 bool)
+                elif opt == 'close_child_stdout':
+                    watcher['close_child_stdout'] = dget(section,
+                                                         "close_child_stdout",
+                                                         False, bool)
+                elif opt == 'close_child_stderr':
+                    watcher['close_child_stderr'] = dget(section,
+                                                         "close_child_stderr",
+                                                         False, bool)
                 else:
                     # freeform
                     watcher[opt] = val
