@@ -77,10 +77,24 @@ class Process(object):
 
     - **use_fds**: if True, will not close the fds in the subprocess.
       default: False.
+
+    - **pipe_stdout**: if True, will open a PIPE on stdout. If False, will
+      close it in the forked process. default: True.
+
+    - **pipe_stderr**: if True, will open a PIPE on stderr. If False, will
+      close it in the forked process. default: True.
+
+    - **close_child_stdout**: If True, closes the stdout after the fork.
+      default: False.
+
+    - **close_child_stderr**: If True, closes the stderr after the fork.
+      default: False.
     """
     def __init__(self, wid, cmd, args=None, working_dir=None, shell=False,
                  uid=None, gid=None, env=None, rlimits=None, executable=None,
-                 use_fds=False, watcher=None, spawn=True):
+                 use_fds=False, watcher=None, spawn=True,
+                 pipe_stdout=True, pipe_stderr=True,
+                 close_child_stdout=False, close_child_stderr=False):
 
         self.wid = wid
         self.cmd = cmd
@@ -94,6 +108,10 @@ class Process(object):
         self.executable = executable
         self.use_fds = use_fds
         self.watcher = watcher
+        self.pipe_stdout = pipe_stdout
+        self.pipe_stderr = pipe_stderr
+        self.close_child_stdout = close_child_stdout
+        self.close_child_stderr = close_child_stderr
 
         if spawn:
             self.spawn()
@@ -102,6 +120,12 @@ class Process(object):
         args = self.format_args()
 
         def preexec_fn():
+            if self.close_child_stdout:
+                os.close(1)
+
+            if self.close_child_stderr:
+                os.close(2)
+
             os.setsid()
 
             for limit, value in self.rlimits.items():
@@ -124,11 +148,17 @@ class Process(object):
             if self.uid:
                 os.setuid(self.uid)
 
+        extra = {}
+        if self.pipe_stdout:
+            extra['stdout'] = PIPE
+
+        if self.pipe_stderr:
+            extra['stderr'] = PIPE
+
         self._worker = Popen(args, cwd=self.working_dir,
                              shell=self.shell, preexec_fn=preexec_fn,
                              env=self.env, close_fds=not self.use_fds,
-                             stdout=PIPE, stderr=PIPE,
-                             executable=self.executable)
+                             executable=self.executable, **extra)
 
         self.started = time.time()
 
@@ -196,8 +226,10 @@ class Process(object):
                 if self._worker.poll() is None:
                     return self._worker.terminate()
             finally:
-                self._worker.stderr.close()
-                self._worker.stdout.close()
+                if self._worker.stderr is not None:
+                    self._worker.stderr.close()
+                if self._worker.stdout is not None:
+                    self._worker.stdout.close()
         except NoSuchProcess:
             pass
 
