@@ -1,13 +1,13 @@
 from collections import defaultdict
-from circus import zmq
 import json
 from itertools import chain
 import os
 import errno
 import socket
 
-from zmq.eventloop import ioloop, zmqstream
+import zmq
 
+from circus._zmq import ioloop, zmqstream
 from circus.commands import get_commands
 from circus.client import CircusClient
 from circus.stats.collector import WatcherStatsCollector, SocketStatsCollector
@@ -16,8 +16,8 @@ from circus import logger
 
 
 class StatsStreamer(object):
-    def __init__(self, endpoint, pubsub_endoint, stats_endpoint, ssh_server,
-                 delay=1., loop=None):
+    def __init__(self, endpoint, pubsub_endoint, stats_endpoint,
+                 ssh_server=None, delay=1., loop=None):
         self.topic = 'watcher.'
         self.delay = delay
         self.ctx = zmq.Context()
@@ -176,7 +176,7 @@ class StatsStreamer(object):
         """called each time circusd sends an event"""
         # maintains a periodic callback to compute mem and cpu consumption for
         # each pid.
-        logger.debug('Received an event from circusd: %s' % data)
+        logger.debug('Received an event from circusd: %s' % str(data))
         topic, msg = data
         try:
             watcher = topic.split('.')[1:-1][0]
