@@ -154,6 +154,12 @@ class Watcher(object):
 
     - **virtualenv** -- The root directory of a virtualenv. If provided, the
       watcher will load the environment for its execution. (default: None)
+
+    - **close_child_stdout**: If True, closes the stdout after the fork.
+      default: False.
+
+    - **close_child_stderr**: If True, closes the stderr after the fork.
+      default: False.
     """
     def __init__(self, name, cmd, args=None, numprocesses=1, warmup_delay=0.,
                  working_dir=None, shell=False, uid=None, max_retry=5,
@@ -164,7 +170,8 @@ class Watcher(object):
                  singleton=False, use_sockets=False, copy_env=False,
                  copy_path=False, max_age=0, max_age_variance=30,
                  hooks=None, respawn=True, autostart=True, on_demand=False,
-                 virtualenv=None, **options):
+                 virtualenv=None, close_child_stdout=False,
+                 close_child_stderr=False, **options):
         self.name = name
         self.use_sockets = use_sockets
         self.on_demand = on_demand
@@ -196,6 +203,8 @@ class Watcher(object):
         self.hooks = self._resolve_hooks(hooks)
         self.respawn = respawn
         self.autostart = autostart
+        self.close_child_stdout = close_child_stdout
+        self.close_child_stderr = close_child_stderr
         self.loop = loop or ioloop.IOLoop.instance()
 
         if singleton and self.numprocesses not in (0, 1):
@@ -207,7 +216,8 @@ class Watcher(object):
                           "max_retry", "cmd", "args", "graceful_timeout",
                           "executable", "use_sockets", "priority", "copy_env",
                           "singleton", "stdout_stream_conf", "on_demand",
-                          "stderr_stream_conf", "max_age", "max_age_variance")
+                          "stderr_stream_conf", "max_age", "max_age_variance",
+                          "close_child_stdout", "close_child_stderr")
                          + tuple(options.keys()))
 
         if not working_dir:
@@ -243,19 +253,16 @@ class Watcher(object):
 
     def _create_redirectors(self):
         if self.stdout_stream:
-            if (self.stdout_redirector is not None and
-                    self.stdout_redirector.running):
-                self.stdout_redirector.kill()
+            if self.stdout_redirector is not None:
+                self.stdout_redirector.stop()
             self.stdout_redirector = get_pipe_redirector(
                 self.stdout_stream, loop=self.loop)
         else:
             self.stdout_redirector = None
 
         if self.stderr_stream:
-            if (self.stderr_redirector is not None and
-                    self.stderr_redirector.running):
-                self.stderr_redirector.kill()
-
+            if self.stderr_redirector is not None:
+                self.stderr_redirector.stop()
             self.stderr_redirector = get_pipe_redirector(
                 self.stderr_stream, loop=self.loop)
         else:
@@ -435,6 +442,9 @@ class Watcher(object):
         cmd = util.replace_gnu_args(self.cmd, sockets=self._get_sockets_fds())
         self._process_counter += 1
         nb_tries = 0
+        pipe_stdout = self.stdout_redirector is not None
+        pipe_stderr = self.stderr_redirector is not None
+
         while nb_tries < self.max_retry or self.max_retry == -1:
             process = None
             try:
@@ -443,15 +453,19 @@ class Watcher(object):
                                   shell=self.shell, uid=self.uid, gid=self.gid,
                                   env=self.env, rlimits=self.rlimits,
                                   executable=self.executable,
-                                  use_fds=self.use_sockets, watcher=self)
+                                  use_fds=self.use_sockets, watcher=self,
+                                  pipe_stdout=pipe_stdout,
+                                  pipe_stderr=pipe_stderr,
+                                  close_child_stdout=self.close_child_stdout,
+                                  close_child_stderr=self.close_child_stderr)
 
                 # stream stderr/stdout if configured
-                if self.stdout_redirector is not None:
+                if pipe_stdout:
                     self.stdout_redirector.add_redirection('stdout',
                                                            process,
                                                            process.stdout)
 
-                if self.stderr_redirector is not None:
+                if pipe_stderr:
                     self.stderr_redirector.add_redirection('stderr',
                                                            process,
                                                            process.stderr)
@@ -478,10 +492,10 @@ class Watcher(object):
         """
         # remove redirections
         if self.stdout_redirector is not None:
-            self.stdout_redirector.remove_redirection('stdout', process)
+            self.stdout_redirector.remove_redirection(process.stdout)
 
         if self.stderr_redirector is not None:
-            self.stderr_redirector.remove_redirection('stderr', process)
+            self.stderr_redirector.remove_redirection(process.stderr)
 
         logger.debug("%s: kill process %s", self.name, process.pid)
         try:
@@ -571,10 +585,12 @@ class Watcher(object):
         logger.debug('stopping the %s watcher' % self.name)
         # stop redirectors
         if self.stdout_redirector is not None:
-            self.stdout_redirector.kill()
+            self.stdout_redirector.stop()
+            self.stdout_redirector = None
 
         if self.stderr_redirector is not None:
-            self.stderr_redirector.kill()
+            self.stderr_redirector.stop()
+            self.stderr_redirector = None
 
         limit = time.time() + self.graceful_timeout
 
